#!/usr/bin/env python

"""rStatic (Rebatch Static Site Generator).

Create by Joshua Powell on 2020-OCT-16.

Copyright (c) 2020 Joshua Powell. All rights reserved.

For license and copyright information please see the LICENSE.md (the "License")
document packaged with this software. This file and all other files included in
this packaged software may not be used in any manner except in compliance with
the License. Software distributed under this License is distributed on an "AS
IS" BASIS, WITHOUT WARRANTY, OR CONDITIONS OF ANY KIND, either express or
implied.

See the License for the specific language governing permission and limitations
under the License.
"""


import logging
import flask

"""System Logging.

System logging enables us to retain useful activity within the system in
server logs. Log messages are written to the Terminal or Application Runner
(e.g., Supervisor) server logs.

Below sets up the `basicConfig` which opens a stream that allows us to add
formatted log messages to the root logger.

@param (object) logger
    Provides the ability to write directly to the logger with the info(),
    warning(), error(), and critical() methods

See the official Python::logging documentation for more Information
https://docs.python.org/2/library/logging.html
"""
logging.basicConfig(level=logging.DEBUG)
logger = logging.getLogger(__name__)



#!/usr/bin/env python

"""rStatic (Rebatch Static Site Generator).

Create by Joshua Powell on 2020-OCT-16.

Copyright (c) 2020 Joshua Powell. All rights reserved.

For license and copyright information please see the LICENSE.md (the "License")
document packaged with this software. This file and all other files included in
this packaged software may not be used in any manner except in compliance with
the License. Software distributed under this License is distributed on an "AS
IS" BASIS, WITHOUT WARRANTY, OR CONDITIONS OF ANY KIND, either express or
implied.

See the License for the specific language governing permission and limitations
under the License.
"""


import os

from . import flask
from . import logger


class Application(object):
    """Create class-based Flask application."""

    def __init__(self, name, environment="default", ):
        """Application Constructor.

        :param (class) self
            The representation of the instantiated Class Instance
        :param (str) name
            The name of the application
        :param (str) environment
            The name of the enviornment in which to load the application
        """
        self.name = name
        self.environment = environment

        """Create our base Flask application
        """
        logger.info('Starting rStatic')
        app = flask.Flask(__name__, static_url_path='/static')

        self.app = app

        """Import configuration based on environment.
        """
        logger.info('Locating environment configuration file')

        config_ = ('%s/config/%s.json') % (os.getcwd(), environment)

        """Parse the JSON configuration file content.
        """
        logger.info('Loading environment variables from configuration file')
        self.app.config.from_json(config_)

        logger.info('rStatic exited with 0.')



#!/usr/bin/env python

"""rStatic (Rebatch Static Site Generator).

Copyright (c) 2020 Joshua Powell. All rights reserved.

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

See the License for the specific language governing permissions and
limitations under the License.
"""

from setuptools import find_packages
from setuptools import setup

"""PyPi Information

    Additional PyPi information and how to configure the setup definition
    can be found at https://pypi.org/classifiers/
"""

setup(
    name='rstatic',
    version='0.0.1',
    author='Joshua Powell',
    description='Open-source static site generator.',
    url='https://rebatch.io/rstatic',
    packages=find_packages(),
    include_package_data=True,
    zip_safe = False,
    install_requires=[
        'flask',
        'frozen-flask',
        'flask-flatpages',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Operating System :: POSIX :: Linux",
        "Framework :: Flask",
        "Natural Language :: English",
        "Topic :: Software Development :: Libraries :: Application Frameworks"
    ],
)